@@ -38,7 +38,7 @@ from . import utils
 from ._environ import environ, BaseEnviron
 from .decorator import cached_property
 
-_logger = environ.get_logger("utils")
+_logger = environ.get_logger("tools")
 
 
 class Parser(object):
@@ -181,7 +181,15 @@ class Meta(type):
         return lambda self: self.config.get(key)
 
 
-class ToolExecError(Exception):
+class ToolError(Exception):
+    pass
+
+
+class ToolNotFound(ToolError):
+    pass
+
+
+class ToolExecError(ToolError):
     pass
 
 
@@ -330,10 +338,11 @@ class Tool(metaclass=Meta):
 
         return utils.Popen(*[*executable_cmdline, *args], **kwargs)
 
+    @utils.timeoutable
     def exec(
             self,
             *args: [Any],
-            timeout: utils.TimeoutType = None,
+            timeout: utils.Timeout = None,
             ignore_errors: bool = False,
             log_output: bool = False,
     ) -> str:
@@ -348,7 +357,11 @@ class Tool(metaclass=Meta):
         process = self.popen(*args, capture_output=True)
 
         try:
-            out, err = process.exec(timeout, log_stdout=log_output, log_stderr=log_output)
+            out, err = process.exec(
+                timeout=timeout,
+                on_stdout=_logger.info if log_output else None,
+                on_stderr=_logger.error if log_output else None
+            )
             if not ignore_errors and process.poll() not in (0, None):
                 if isinstance(err, bytes):
                     err = err.decode(errors="ignore")
@@ -356,7 +369,7 @@ class Tool(metaclass=Meta):
                 elif isinstance(err, str):
                     err = err.strip()
                 if err:
-                    raise Exception(err)
+                    raise ToolExecError(err)
 
             if isinstance(out, bytes):
                 out = out.decode(errors="ignore")
@@ -374,9 +387,6 @@ class Tool(metaclass=Meta):
 
 
 class ToolContainer(object):
-    system: str = property(lambda self: self.config["system"])
-    processor: str = property(lambda self: self.config["processor"])
-    architecture: str = property(lambda self: self.config["architecture"])
 
     def __init__(self, env: BaseEnviron, **kwargs):
         self.environ = env
@@ -385,10 +395,22 @@ class ToolContainer(object):
         self.config.setdefault("processor", platform.processor().lower())
         self.config.setdefault("architecture", platform.architecture()[0].lower())
 
+    @property
+    def system(self) -> str:
+        return self.config["system"]
+
+    @property
+    def processor(self) -> str:
+        return self.config["processor"]
+
+    @property
+    def architecture(self) -> str:
+        return self.config["architecture"]
+
     @cached_property
     def items(self) -> Mapping[str, Tool]:
         items = {}
-        for key, value in self.environ.get_configs("GENERAL_TOOL_").items():
+        for key, value in self.environ.config.get_namespace("GENERAL_TOOL_").items():
             if not isinstance(value, dict):
                 warnings.warn(f"dict was expected, got {type(value)}, ignored.")
                 continue
@@ -399,8 +421,12 @@ class ToolContainer(object):
     def __iter__(self) -> Iterator[Tool]:
         return iter(self.items.values())
 
-    def __getitem__(self, item) -> Union[Tool, None]:
-        return self.items[item] if item in self.items else None
+    def __getitem__(self, item) -> Tool:
+        if item not in self.items:
+            raise ToolNotFound(f"Not found tool {item}")
+        return self.items[item]
 
-    def __getattr__(self, item) -> Union[Tool, None]:
-        return self.items[item] if item in self.items else None
+    def __getattr__(self, item) -> Tool:
+        if item not in self.items:
+            raise ToolNotFound(f"Not found tool {item}")
+        return self.items[item]
