@@ -34,10 +34,12 @@ import os
 import sys
 import textwrap
 import traceback
-from abc import ABC
-from argparse import ArgumentParser, Action, SUPPRESS, RawDescriptionHelpFormatter
-from typing import Tuple, Type, Optional
+from argparse import ArgumentParser, Action, Namespace, RawDescriptionHelpFormatter, SUPPRESS
+from importlib.util import module_from_spec
+from pkgutil import walk_packages
+from typing import Tuple, Type, Optional, List, Generator, IO
 
+import rich
 from rich import get_console
 from rich.prompt import IntPrompt
 from rich.table import Table
@@ -48,26 +50,7 @@ from ..decorator import cached_property
 from ..utils import ignore_error
 
 
-class BaseCommand(abc.ABC):
-
-    def main(self, *args, **kwargs) -> None:
-        try:
-            self.on_main_init()
-            logging.basicConfig(
-                level=logging.INFO,
-                format="%(message)s",
-                datefmt="[%X]",
-                handlers=[LogHandler()]
-            )
-            exit(self(*args, **kwargs))
-        finally:
-            self.on_main_deinit()
-
-    def on_main_init(self):
-        pass
-
-    def on_main_deinit(self):
-        pass
+class BaseCommand(metaclass=abc.ABCMeta):
 
     @property
     def name(self):
@@ -85,22 +68,27 @@ class BaseCommand(abc.ABC):
     def description(self) -> str:
         return textwrap.dedent((self.__doc__ or "").strip())
 
-    @cached_property
-    def argument_parser(self) -> ArgumentParser:
-        return self.create_argument_parser()
-
     @property
     def known_errors(self) -> Tuple[Type[BaseException]]:
         return tuple()
 
     @abc.abstractmethod
-    def add_arguments(self, parser: ArgumentParser) -> None:
+    def run(self, args: List[str]) -> Optional[int]:
         pass
 
-    def create_argument_parser(self):
+    def print_help(self, file: IO[str] = None):
+        return self._argument_parser.print_help(file=file)
 
+    def parse_args(self, args: List[str] = None) -> Namespace:
+        return self._argument_parser.parse_args(args=args)
+
+    def parse_known_args(self, args: List[str] = None) -> Tuple[Namespace, List[str]]:
+        return self._argument_parser.parse_known_args(args=args)
+
+    @cached_property
+    def _argument_parser(self) -> ArgumentParser:
         description = self.description.strip()
-        if description and self.environ.description:
+        if description and self.environ.description != NotImplemented:
             description += os.linesep + os.linesep
             description += self.environ.description
 
@@ -109,12 +97,18 @@ class BaseCommand(abc.ABC):
             description=description,
             conflict_handler="resolve"
         )
-        self.add_base_arguments(parser)
-        self.add_arguments(parser)
+        self.init_base_arguments(parser)
+        self.init_arguments(parser)
 
         return parser
 
-    def add_base_arguments(self, parser: ArgumentParser):
+    @abc.abstractmethod
+    def init_arguments(self, parser: ArgumentParser) -> None:
+        pass
+
+    def init_base_arguments(self, parser: ArgumentParser):
+
+        command_self = self
 
         class VerboseAction(Action):
 
@@ -124,8 +118,8 @@ class BaseCommand(abc.ABC):
         class DebugAction(Action):
 
             def __call__(self, parser, namespace, values, option_string=None):
-                environ.debug = True
-                environ.logger.setLevel(logging.DEBUG)
+                command_self.environ.debug = True
+                command_self.environ.logger.setLevel(logging.DEBUG)
 
         class BooleanOptionalAction(Action):
 
@@ -136,21 +130,30 @@ class BaseCommand(abc.ABC):
 
             def __call__(self, parser, namespace, values, option_string=None):
                 if option_string in self.option_strings:
-                    environ.show_log_time = not option_string.startswith("--no-")
+                    value = not option_string.startswith("--no-")
+                    handler = LogHandler.get_instance()
+                    if handler:
+                        handler.show_time = value
+                    command_self.environ.set_config("SHOW_LOG_TIME", value)
 
         class LogLevelAction(BooleanOptionalAction):
 
             def __call__(self, parser, namespace, values, option_string=None):
                 if option_string in self.option_strings:
-                    environ.show_log_level = not option_string.startswith("--no-")
+                    value = not option_string.startswith("--no-")
+                    handler = LogHandler.get_instance()
+                    if handler:
+                        handler.show_level = value
+                    command_self.environ.set_config("SHOW_LOG_LEVEL", value)
 
-        parser.add_argument("--version", action="version", version=self.environ.version)
+        if self.environ.version != NotImplemented:
+            parser.add_argument("--version", action="version", version=self.environ.version)
 
         group = parser.add_argument_group(title="log arguments")
         group.add_argument("--verbose", action=VerboseAction, nargs=0, const=True, dest=SUPPRESS,
                            help="increase log verbosity")
         group.add_argument("--debug", action=DebugAction, nargs=0, const=True, dest=SUPPRESS,
-                           help="enable debug mode and increase log verbosity")
+                           help=f"enable debug mode and increase {self.environ.name}'s log verbosity")
 
         if LogHandler.get_instance():
             group.add_argument("--time", "--no-time", action=LogTimeAction, nargs=0, dest=SUPPRESS,
@@ -159,7 +162,8 @@ class BaseCommand(abc.ABC):
                                help="show log level")
 
     def add_android_arguments(self, parser: ArgumentParser):
-        from linktools.android import Adb, Device, AdbError
+        from ..android import Adb, AdbError, Device as AdbDevice
+
         cache_path = environ.get_temp_path("cache", "device", "android", create_parent=True)
 
         def parse_handler(fn):
@@ -175,7 +179,7 @@ class BaseCommand(abc.ABC):
 
         @parse_handler
         def parse_device():
-            devices = Adb.devices(alive=True)
+            devices = tuple(Adb.list_devices(alive=True))
             if len(devices) == 0:
                 raise AdbError("no devices/emulators found")
 
@@ -191,8 +195,8 @@ class BaseCommand(abc.ABC):
             for i in range(len(devices)):
                 table.add_row(
                     str(i + offset),
-                    devices[i].id,
-                    ignore_error(lambda: devices[i].get_prop("ro.product.model", timeout=1)) or "",
+                    ignore_error(lambda: devices[i].id),
+                    ignore_error(lambda: devices[i].name) or "",
                 )
 
             console = get_console()
@@ -210,7 +214,7 @@ class BaseCommand(abc.ABC):
             def __call__(self, parser, namespace, values, option_string=None):
                 @parse_handler
                 def wrapper():
-                    return Device(str(values))
+                    return AdbDevice(str(values))
 
                 setattr(namespace, self.dest, wrapper)
 
@@ -219,7 +223,7 @@ class BaseCommand(abc.ABC):
             def __call__(self, parser, namespace, values, option_string=None):
                 @parse_handler
                 def wrapper():
-                    return Device(Adb.exec("-d", "get-serialno").strip(" \r\n"))
+                    return AdbDevice(Adb.exec("-d", "get-serialno").strip(" \r\n"))
 
                 setattr(namespace, self.dest, wrapper)
 
@@ -228,7 +232,7 @@ class BaseCommand(abc.ABC):
             def __call__(self, parser, namespace, values, option_string=None):
                 @parse_handler
                 def wrapper():
-                    return Device(Adb.exec("-e", "get-serialno").strip(" \r\n"))
+                    return AdbDevice(Adb.exec("-e", "get-serialno").strip(" \r\n"))
 
                 setattr(namespace, self.dest, wrapper)
 
@@ -240,10 +244,9 @@ class BaseCommand(abc.ABC):
                     addr = str(values)
                     if addr.find(":") < 0:
                         addr = addr + ":5555"
-                    devices = Adb.devices()
-                    if addr not in [device.id for device in devices]:
+                    if addr not in [device.id for device in Adb.list_devices()]:
                         Adb.exec("connect", addr, log_output=True)
-                    return Device(addr)
+                    return AdbDevice(addr)
 
                 setattr(namespace, self.dest, wrapper)
 
@@ -254,9 +257,9 @@ class BaseCommand(abc.ABC):
                 def wrapper():
                     if os.path.exists(cache_path):
                         with open(cache_path, "rt") as fd:
-                            result = fd.read().strip()
-                            if len(result) > 0:
-                                return Device(result)
+                            device_id = fd.read().strip()
+                        if len(device_id) > 0:
+                            return AdbDevice(device_id)
                     raise AdbError("no device used last time")
 
                 setattr(namespace, self.dest, wrapper)
@@ -274,7 +277,8 @@ class BaseCommand(abc.ABC):
                            help="use last device")
 
     def add_ios_arguments(self, parser: ArgumentParser):
-        from linktools.ios import Sib, SibError, Device
+        from ..ios import Sib, SibError, Device as SibDevice
+
         cache_path = environ.get_temp_path("cache", "device", "ios", create_parent=True)
 
         def parse_handler(fn):
@@ -290,7 +294,7 @@ class BaseCommand(abc.ABC):
 
         @parse_handler
         def parse_device():
-            devices = Sib.devices()
+            devices = tuple(Sib.list_devices(alive=True))
             if len(devices) == 0:
                 raise SibError("no devices/emulators found")
 
@@ -307,7 +311,7 @@ class BaseCommand(abc.ABC):
                 table.add_row(
                     str(i + offset),
                     ignore_error(lambda: devices[i].id),
-                    ignore_error(lambda: devices[i].name),
+                    ignore_error(lambda: devices[i].name) or "",
                 )
 
             console = get_console()
@@ -325,7 +329,7 @@ class BaseCommand(abc.ABC):
             def __call__(self, parser, namespace, values, option_string=None):
                 @parse_handler
                 def wrapper():
-                    return Device(str(values))
+                    return SibDevice(str(values))
 
                 setattr(namespace, self.dest, wrapper)
 
@@ -336,9 +340,9 @@ class BaseCommand(abc.ABC):
                 def wrapper():
                     if os.path.exists(cache_path):
                         with open(cache_path, "rt") as fd:
-                            result = fd.read().strip()
-                            if len(result) > 0:
-                                return Device(result)
+                            device_id = fd.read().strip()
+                        if len(device_id) > 0:
+                            return SibDevice(device_id)
                     raise SibError("no device used last time")
 
                 setattr(namespace, self.dest, wrapper)
@@ -351,14 +355,13 @@ class BaseCommand(abc.ABC):
                     address = str(values)
                     host, port = address.split(":", maxsplit=1)
                     Sib.exec("remote", "connect", "--host", host, "--port", port, log_output=True)
-                    for device in Sib.devices():
+                    for device in Sib.list_devices():
                         if address == device.address:
                             return device
 
                 setattr(namespace, self.dest, wrapper)
 
-        group = parser.add_argument_group(title="sib arguments")
-        group = group.add_mutually_exclusive_group()
+        group = parser.add_argument_group(title="sib arguments").add_mutually_exclusive_group()
         group.add_argument("-u", "--udid", metavar="UDID", dest="parse_device", action=UdidAction,
                            help="specify unique device identifier", default=parse_device)
         group.add_argument("-c", "--connect", metavar="IP:PORT", dest="parse_device", action=ConnectAction,
@@ -366,9 +369,105 @@ class BaseCommand(abc.ABC):
         group.add_argument("-l", "--last", dest="parse_device", nargs=0, const=True, action=LastAction,
                            help="use last device")
 
-    @abc.abstractmethod
-    def run(self, args: [str]) -> Optional[int]:
-        pass
+    def add_device_arguments(self, parser: ArgumentParser):
+        from ..device import Bridge, BridgeError
+
+        cache_path = environ.get_temp_path("cache", "device", "mobile", create_parent=True)
+
+        def parse_handler(fn):
+            @functools.wraps(fn)
+            def wrapper(*args, **kwargs):
+                device = fn(*args, **kwargs)
+                if device is not None:
+                    with open(cache_path, "wt+") as fd:
+                        fd.write(device.id)
+                return device
+
+            return wrapper
+
+        @parse_handler
+        def parse_device():
+            devices = tuple(Bridge.list_devices(alive=True))
+            if len(devices) == 0:
+                raise BridgeError("no devices/emulators found")
+
+            if len(devices) == 1:
+                return devices[0]
+
+            table = Table(show_lines=True)
+            table.add_column("Index", justify="right", style="cyan", no_wrap=True)
+            table.add_column("ID", style="magenta")
+            table.add_column("Name", style="magenta")
+
+            offset = 1
+            for i in range(len(devices)):
+                table.add_row(
+                    str(i + offset),
+                    ignore_error(lambda: devices[i].id),
+                    ignore_error(lambda: devices[i].name) or "",
+                )
+
+            console = get_console()
+            console.print(table)
+
+            prompt = f"More than one device/emulator. {os.linesep}" \
+                     f"Enter device index"
+            choices = [str(i) for i in range(offset, len(devices) + offset, 1)]
+            index = IntPrompt.ask(prompt, choices=choices, default=offset, console=console)
+
+            return devices[index - offset]
+
+        class IDAction(Action):
+
+            def __call__(self, parser, namespace, values, option_string=None):
+                @parse_handler
+                def wrapper():
+                    device_id = str(values)
+                    for device in Bridge.list_devices():
+                        if device.id == device_id:
+                            return device
+                    raise BridgeError(f"no devices/emulators with {device_id} found")
+
+                setattr(namespace, self.dest, wrapper)
+
+        class LastAction(Action):
+
+            def __call__(self, parser, namespace, values, option_string=None):
+                @parse_handler
+                def wrapper():
+                    if os.path.exists(cache_path):
+                        with open(cache_path, "rt") as fd:
+                            device_id = fd.read().strip()
+                        if len(device_id) > 0:
+                            for device in Bridge.list_devices():
+                                if device.id == device_id:
+                                    return device
+                    raise BridgeError("no device used last time")
+
+                setattr(namespace, self.dest, wrapper)
+
+        group = parser.add_argument_group(title="mobile device arguments").add_mutually_exclusive_group()
+        group.add_argument("-i", "--id", metavar="ID", dest="parse_device", action=IDAction,
+                           help="specify unique device identifier", default=parse_device)
+        group.add_argument("-l", "--last", dest="parse_device", nargs=0, const=True, action=LastAction,
+                           help="use last device")
+
+    def main(self, *args, **kwargs) -> None:
+        if rich.get_console().is_terminal:
+            logging.basicConfig(
+                level=logging.INFO,
+                format="%(message)s",
+                datefmt="[%X]",
+                handlers=[LogHandler()]
+            )
+        else:
+            logging.basicConfig(
+                level=logging.INFO,
+                format="[%(asctime)s] %(levelname)s %(module)s %(funcName)s %(message)s",
+                datefmt="%H:%M:%S"
+            )
+
+        exit(self(*args, **kwargs))
 
     def __call__(self, args: [str] = None) -> int:
         try:
@@ -397,25 +496,19 @@ class BaseCommand(abc.ABC):
         return exit_code
 
 
-class AndroidCommand(BaseCommand, ABC):
-
-    @property
-    def known_errors(self) -> Tuple[Type[BaseException]]:
-        from linktools.android import AdbError
-        return AdbError,
-
-    def add_base_arguments(self, parser: ArgumentParser):
-        super().add_base_arguments(parser)
-        self.add_android_arguments(parser)
-
-
-class IOSCommand(BaseCommand, ABC):
-
-    @property
-    def known_errors(self) -> Tuple[Type[BaseException]]:
-        from linktools.ios import SibError
-        return SibError,
-
-    def add_base_arguments(self, parser: ArgumentParser):
-        super().add_base_arguments(parser)
-        self.add_ios_arguments(parser)
+def walk_commands(path: str) -> Generator["BaseCommand", None, None]:
+    for finder, name, is_pkg in sorted(walk_packages(path=[path]), key=lambda i: i[1]):
+        if is_pkg:
+            continue
+        try:
+            spec = finder.find_spec(name)
+            module = module_from_spec(spec)
+            spec.loader.exec_module(module)
+            command = getattr(module, "command", None)
+            if command and isinstance(command, BaseCommand):
+                yield command
+        except Exception as e:
+            environ.logger.warning(
+                f"Ignore {name}, caused by {e.__class__.__name__}: {e}",
+                exc_info=e if environ.debug else None
+            )
