@@ -30,7 +30,7 @@ from argparse import ArgumentParser
 from typing import Optional
 
 from linktools import utils, environ
-from linktools.cli import AndroidCommand
+from linktools.cli.android import AndroidCommand
 from linktools.frida.android import AndroidFridaServer
 
 
@@ -39,7 +39,7 @@ class Command(AndroidCommand):
     Easy to use objection (require Android device rooted)
     """
 
-    def add_arguments(self, parser: ArgumentParser) -> None:
+    def init_arguments(self, parser: ArgumentParser) -> None:
         parser.add_argument("-p", "--package", action="store", default=None,
                             help="target package (default: frontmost application)")
         parser.add_argument("-s", "--startup-command", action="append", default=[],
@@ -60,7 +60,7 @@ class Command(AndroidCommand):
                             help="redirect traffic to target port (default: 8080)")
 
     def run(self, args: [str]) -> Optional[int]:
-        args = self.argument_parser.parse_args(args)
+        args = self.parse_args(args)
         device = args.parse_device()
 
         with AndroidFridaServer(device=device, local_port=utils.pick_unused_port()) as server:
