@@ -197,7 +197,7 @@ class Command(BaseCommand):
     Match files with regular expression
     """
 
-    def add_arguments(self, parser: ArgumentParser) -> None:
+    def init_arguments(self, parser: ArgumentParser) -> None:
         parser.add_argument('-i', '--ignore-case', action='store_true', default=False,
                             help='ignore case')
         parser.add_argument('pattern', action='store', default=None,
@@ -206,7 +206,7 @@ class Command(BaseCommand):
                             help='target files path')
 
     def run(self, args: [str]) -> Optional[int]:
-        args = self.argument_parser.parse_args(args)
+        args = self.parse_args(args)
 
         flags = 0
         if args.ignore_case:
