@@ -31,19 +31,21 @@ import threading
 import typing
 
 _T = typing.TypeVar('_T')
+_MISSING = object()
 
 
 def singleton(cls: typing.Type[_T]) -> typing.Callable[..., _T]:
-    instances = {}
+    instance = _MISSING
     lock = threading.RLock()
 
     @functools.wraps(cls)
     def wrapper(*args, **kwargs):
-        if cls not in instances:
+        nonlocal instance
+        if instance is _MISSING:
             with lock:
-                if cls not in instances:
-                    instances[cls] = cls(*args, **kwargs)
-        return instances[cls]
+                if instance is _MISSING:
+                    instance = cls(*args, **kwargs)
+        return instance
 
     return wrapper
 
@@ -81,7 +83,6 @@ def synchronized(lock=None):
 
 
 class cached_property:
-    __missing__ = object()
 
     def __init__(self, func):
         self.func = func
@@ -112,12 +113,12 @@ class cached_property:
                 f"instance to cache {self.attrname!r} property."
             )
             raise TypeError(msg) from None
-        val = cache.get(self.attrname, self.__missing__)
-        if val is self.__missing__:
+        val = cache.get(self.attrname, _MISSING)
+        if val is _MISSING:
             with self.lock:
                 # check if another thread filled cache while we awaited lock
-                val = cache.get(self.attrname, self.__missing__)
-                if val is self.__missing__:
+                val = cache.get(self.attrname, _MISSING)
+                if val is _MISSING:
                     val = self.func(instance)
                     try:
                         cache[self.attrname] = val
@@ -131,5 +132,32 @@ class cached_property:
         return val
 
 
-class locked_cached_property(cached_property):
-    pass
+class classproperty:
+    """
+    Decorator that converts a method with a single cls argument into a property
+    that can be accessed directly from the class.
+    """
+
+    def __init__(self, func=None):
+        self.func = func
+
+    def __get__(self, instance, owner=None):
+        return self.func(owner)
+
+
+class cached_classproperty:
+
+    def __init__(self, func):
+        self.func = func
+        self.__doc__ = func.__doc__
+        self.lock = threading.RLock()
+        self.val = _MISSING
+
+    def __get__(self, instance, owner=None):
+        if self.val is _MISSING:
+            with self.lock:
+                # check if another thread filled cache while we awaited lock
+                if self.val is _MISSING:
+                    self.val = self.func(owner)
+
+        return self.val
