@@ -22,11 +22,13 @@ from ._utils import Counter
 from .script import FridaUserScript, FridaEvalCode, FridaScriptFile
 from .server import FridaServer
 from .. import utils, environ
+from ..reactor import Reactor
+from ..version import __release__
 
 _logger = environ.get_logger("frida.app")
 
 
-class FridaReactor(utils.Reactor):
+class FridaReactor(Reactor):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -264,7 +266,7 @@ class FridaScriptHandler(metaclass=abc.ABCMeta):
         脚本结束回调函数，默认只打印log
         :param script: frida的脚本
         """
-        self.on_script_log(script, self.LogLevel.INFO, f"{script} destroyed.", None)
+        self.on_script_log(script, self.LogLevel.DEBUG, f"{script} destroyed", None)
 
 
 class FridaFileHandler(metaclass=abc.ABCMeta):
@@ -290,7 +292,8 @@ class FridaManager:
     def sessions(self) -> Dict[int, FridaSession]:
         with self._lock:
             sessions = {}
-            for pid, session in self._sessions.items():
+            for pid in list(self._sessions.keys()):
+                session = self._sessions.get(pid)
                 if not session.is_detached:
                     sessions[pid] = session
                     continue
@@ -304,7 +307,7 @@ class FridaManager:
                 if not session.is_detached:
                     return session
                 self._sessions.pop(pid)
-        return None
+            return None
 
     def set_session(self, session: FridaSession):
         with self._lock:
@@ -330,14 +333,14 @@ class FridaManager:
         device.on("lost", cb_lost)
 
         def cancel():
-            utils.ignore_error(device.off, "spawn-added", cb_spawn_added)
-            utils.ignore_error(device.off, "spawn-removed", cb_spawn_removed)
-            utils.ignore_error(device.off, "child-added", cb_child_added)
-            utils.ignore_error(device.off, "child-removed", cb_child_removed)
-            utils.ignore_error(device.off, "output", cb_output)
-            # utils.ignore_error(device.off, "process-crashed", cb_process_crashed)
-            # utils.ignore_error(device.off, "uninjected", cb_uninjected)
-            utils.ignore_error(device.off, "lost", cb_lost)
+            utils.ignore_error(device.off, args=("spawn-added", cb_spawn_added))
+            utils.ignore_error(device.off, args=("spawn-removed", cb_spawn_removed))
+            utils.ignore_error(device.off, args=("child-added", cb_child_added))
+            utils.ignore_error(device.off, args=("child-removed", cb_child_removed))
+            utils.ignore_error(device.off, args=("output", cb_output))
+            # utils.ignore_error(device.off, args=("process-crashed", cb_process_crashed))
+            # utils.ignore_error(device.off, args=("uninjected", cb_uninjected))
+            utils.ignore_error(device.off, args=("lost", cb_lost))
 
         self._register_cancel(device, cancel)
 
@@ -356,7 +359,7 @@ class FridaManager:
         session.on("detached", on_detached)
 
         def cancel():
-            utils.ignore_error(session.off, "detached", on_detached)
+            utils.ignore_error(session.off, args=("detached", on_detached))
 
         self._register_cancel(session, cancel)
 
@@ -377,8 +380,8 @@ class FridaManager:
         script.on("destroyed", on_destroyed)
 
         def cancel():
-            utils.ignore_error(script.off, "message", on_message)
-            utils.ignore_error(script.off, "destroyed", on_destroyed)
+            utils.ignore_error(script.off, args=("message", on_message))
+            utils.ignore_error(script.off, args=("destroyed", on_destroyed))
 
         self._register_cancel(script, cancel)
 
@@ -497,7 +500,7 @@ class FridaApplication(FridaDeviceHandler, FridaSessionHandler, FridaScriptHandl
         self._manager = FridaManager(self._reactor)
 
         # 初始化内置脚本
-        script_name = "frida.min.js" if not environ.debug else "frida.js"
+        script_name = "frida.js" if not __release__ or environ.debug else "frida.min.js"
         self._internal_script = FridaScriptFile(environ.get_asset_path(script_name))
 
         # 初始化需要注入进程的匹配规则
@@ -562,7 +565,8 @@ class FridaApplication(FridaDeviceHandler, FridaSessionHandler, FridaScriptHandl
     def is_running(self) -> bool:
         return self._reactor.is_running()
 
-    def run(self, timeout=None):
+    @utils.timeoutable
+    def run(self, timeout: utils.Timeout = None):
         assert not self.is_running
         try:
             self._init()
@@ -571,19 +575,22 @@ class FridaApplication(FridaDeviceHandler, FridaSessionHandler, FridaScriptHandl
         finally:
             self._deinit()
 
-    def wait(self, timeout=None) -> bool:
+    @utils.timeoutable
+    def wait(self, timeout: utils.Timeout = None) -> bool:
         return self._finished.wait(timeout)
 
     def stop(self):
         self._stop_request.set()
 
     def __enter__(self):
+        assert not self.is_running
         try:
             self._init()
             self._reactor.run()
             return self
-        except:
-            utils.ignore_error(self._deinit)
+        except Exception as e:
+            self._deinit()
+            raise e
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self._reactor.stop()
@@ -688,7 +695,7 @@ class FridaApplication(FridaDeviceHandler, FridaSessionHandler, FridaScriptHandl
             script.exports_sync.load_scripts(self._load_script_files(), self._user_parameters)
         finally:
             if resume:
-                utils.ignore_error(self.device.resume, pid)
+                utils.ignore_error(self.device.resume, args=(pid,))
 
         self._reactor.schedule(lambda: self.on_script_loaded(script))
 
