@@ -38,7 +38,7 @@ from urllib import parse
 
 from filelock import FileLock
 
-from ._utils import Timeout, TimeoutType, get_md5, ignore_error, parse_version
+from ._utils import Timeout, get_md5, ignore_error, parse_version, timeoutable
 from .._environ import environ
 from .._logging import create_log_progress
 from ..decorator import cached_property, singleton
@@ -62,17 +62,17 @@ class _UserAgent(UserAgent):
 def user_agent(style=None) -> str:
     try:
 
-        user_agent = _UserAgent()
+        ua = _UserAgent()
 
         if style:
-            return user_agent[style]
+            return ua[style]
 
-        return user_agent.random
+        return ua.random
 
     except Exception as e:
         _logger.debug(f"fetch user agent error: {e}")
 
-    return environ.get_config("DOWNLOAD_USER_AGENT")
+    return environ.get_config("DOWNLOAD_USER_AGENT", type=str)
 
 
 def make_url(url: str, *paths: str, **kwargs: QueryType) -> str:
@@ -256,7 +256,8 @@ class UrlFile:
             environ.get_temp_path("download", "lock", self._ident, create_parent=True)
         )
 
-    def save(self, save_dir: str = None, save_name: str = None, timeout: TimeoutType = None, **kwargs) -> str:
+    @timeoutable
+    def save(self, save_dir: str = None, save_name: str = None, timeout: Timeout = None, **kwargs) -> str:
         """
         从指定url下载文件
         :param save_dir: 文件路径，如果为空，则保存到temp目录
@@ -267,7 +268,6 @@ class UrlFile:
 
         lock = self._lock
         target_path = self._file_path
-        timeout = Timeout(timeout)
 
         try:
             lock.acquire(timeout=timeout.remain, poll_interval=1)
