@@ -26,8 +26,11 @@
   / ==ooooooooooooooo==.o.  ooo= //   ,`\--{)B     ,"
  /_==__==========__==_ooo__ooo=_/'   /___________,"
 """
+import functools
 import gzip
 import hashlib
+import inspect
+import os
 import random
 import re
 import socket
@@ -35,23 +38,18 @@ import threading
 import time
 import uuid
 from collections.abc import Iterable, Sized
-from typing import Union, Callable, Optional, Type, Any, List, TypeVar
+from typing import Union, Callable, Optional, Type, Any, List, TypeVar, Tuple, Set, Dict
 from urllib.request import urlopen
 
 _T = TypeVar("_T")
-TimeoutType = Union[float, int, "Timeout", None]
 
 
 class Timeout:
 
-    def __init__(self, timeout: TimeoutType):
-        if isinstance(timeout, Timeout):
-            self._deadline = timeout._deadline
-            self._timeout = timeout._timeout
-        else:
-            self._deadline = None
-            self._timeout = timeout
-            self.reset()
+    def __init__(self, timeout: Union[float, int] = None):
+        self._deadline = None
+        self._timeout = timeout
+        self.reset()
 
     @property
     def remain(self) -> Union[float, None]:
@@ -68,29 +66,81 @@ class Timeout:
         if self._timeout is not None and self._timeout >= 0:
             self._deadline = time.time() + self._timeout
 
-    def check(self) -> "bool":
+    def check(self) -> bool:
         if self._deadline is not None:
             if time.time() > self._deadline:
                 return False
         return True
 
-    def ensure(self) -> None:
+    def ensure(self, err_type=TimeoutError, message=None) -> None:
         if not self.check():
-            raise TimeoutError()
+            raise err_type(message)
 
     def __repr__(self):
         return f"Timeout(timeout={self._timeout})"
 
 
+def timeoutable(fn: Callable[..., _T]) -> Callable[..., _T]:
+    timeout_keyword = "timeout"
+
+    timeout_index = -1
+    positional_index = -1
+    keyword_index = -1
+
+    index = 0
+    for key, parameter in inspect.signature(fn).parameters.items():
+        if key == timeout_keyword:
+            timeout_index = index
+            break
+        elif parameter.kind in (parameter.KEYWORD_ONLY, parameter.VAR_KEYWORD):
+            keyword_index = index
+        elif parameter.kind in (parameter.VAR_POSITIONAL,):
+            positional_index = index
+        index += 1
+
+    if timeout_index < 0 and keyword_index < 0:
+        raise RuntimeError(f"Not found timeout parameter in {fn}")
+
+    if 0 <= positional_index < timeout_index:
+        # 如果timeout在*args参数后面，那就只能通过**kwargs访问了
+        timeout_index = -1
+
+    @functools.wraps(fn)
+    def wrapper(*args, **kwargs):
+        if 0 <= timeout_index < len(args):
+            timeout = args[timeout_index]
+            if isinstance(timeout, Timeout):
+                pass
+            elif isinstance(timeout, (float, int, type(None))):
+                args = list(args)
+                args[timeout_index] = Timeout(timeout)
+            else:
+                raise RuntimeError(f"Timeout/int/float was expects, got {type(timeout)}")
+        elif timeout_keyword in kwargs:
+            timeout = kwargs.get(timeout_keyword)
+            if isinstance(timeout, Timeout):
+                pass
+            elif isinstance(timeout, (float, int, type(None))):
+                kwargs[timeout_keyword] = Timeout(timeout)
+            else:
+                raise RuntimeError(f"Timeout/int/float was expects, got {type(timeout)}")
+        else:
+            kwargs[timeout_keyword] = Timeout()
+
+        return fn(*args, **kwargs)
+
+    return wrapper
+
+
 class InterruptableEvent(threading.Event):
     """
     解决 Windows 上 event.wait 不支持 ctrl+c 中断的问题
     """
 
-    def wait(self, timeout: TimeoutType = None):
+    @timeoutable
+    def wait(self, timeout: Timeout = None):
         interval = 1
         wait = super().wait
-        timeout = Timeout(timeout)
         while True:
             t = timeout.remain
             if t is None:
@@ -101,11 +151,18 @@ class InterruptableEvent(threading.Event):
                 break
 
 
-def ignore_error(fn: Callable[..., _T], *args, **kwargs) -> _T:
+def ignore_error(
+        fn: Callable[..., _T], *,
+        args: Tuple[Any, ...] = None, kwargs: Dict[str, Any] = None,
+        default: _T = None) -> _T:
     try:
+        if args is None:
+            args = tuple()
+        if kwargs is None:
+            kwargs = dict()
         return fn(*args, **kwargs)
     except:
-        return None
+        return default
 
 
 # noinspection PyShadowingBuiltins
@@ -123,32 +180,35 @@ def cast(type: Type[_T], obj: Any, default: _T = None) -> Optional[_T]:
         return default
 
 
-def int(obj: Any, default: int = 0) -> "int":
+def cast_int(obj: Any, default: int = 0) -> int:
     """
     转为int
     :param obj: 需要转换的值
     :param default: 默认值
     :return: 转换后的值
     """
-    return cast(type(0), obj, default=default)
+    try:
+        return int(obj)
+    except:
+        return default
 
 
-def bool(obj: Any, default: bool = False) -> "bool":
+def cast_bool(obj: Any, default: bool = False) -> bool:
     """
     转为bool
     :param obj: 需要转换的值
     :param default: 默认值
     :return: 转换后的值
     """
-    bool_type = type(True)
-    if isinstance(obj, bool_type):
+    if isinstance(obj, bool):
         return obj
+    cast_type = bool
     if isinstance(obj, str):
-        return cast(lambda o: o.lower() == "true", obj, default=default)
-    return cast(bool_type, obj, default=default)
+        return obj.lower() in ("true", "yes")
+    return cast(cast_type, obj, default=default)
 
 
-def is_contain(obj: Any, key: Any) -> "bool":
+def is_contain(obj: Any, key: Any) -> bool:
     """
     是否包含内容
     :param obj: 对象
@@ -162,7 +222,7 @@ def is_contain(obj: Any, key: Any) -> "bool":
     return False
 
 
-def is_empty(obj: Any) -> "bool":
+def is_empty(obj: Any) -> bool:
     """
     对象是否为空
     :param obj: 对象
@@ -263,7 +323,7 @@ def pop_item(obj: Any, *keys: Any, type: Type[_T] = None, default: _T = None) ->
 
 
 # 1noinspection PyShadowingBuiltins, PyUnresolvedReferences
-def get_list_item(obj: Any, *keys: Any, type: Type[_T] = None, default: List[_T] = None) -> List[Optional[_T]]:
+def get_list_item(obj: Any, *keys: Any, type: Type[_T] = None, default: List[_T] = None) -> Optional[List[_T]]:
     """
     获取子项（列表）
     :param obj: 对象
@@ -273,7 +333,7 @@ def get_list_item(obj: Any, *keys: Any, type: Type[_T] = None, default: List[_T]
     :return: 子项
     """
     objs = get_item(obj, *keys, default=None)
-    if objs is None or not isinstance(objs, Iterable):
+    if objs is None or not isinstance(objs, (Tuple, List, Set)):
         return default
     result = []
     for obj in objs:
@@ -321,13 +381,32 @@ def gzip_compress(data: Union[str, bytes]) -> bytes:
     return gzip.compress(data)
 
 
-def read_file(path: str, binary: "bool" = True) -> Union[str, bytes]:
-    with open(path, "rb" if binary else 'r') as f:
+def get_path(root_path: str, *paths: [str], create: bool = False, create_parent: bool = False):
+    target_path = parent_path = os.path.abspath(root_path)
+    for path in paths:
+        target_path = os.path.abspath(os.path.join(parent_path, path))
+        common_path = os.path.commonpath([parent_path, target_path])
+        if target_path == parent_path or parent_path != common_path:
+            raise Exception(f"Unsafe path \"{path}\"")
+        parent_path = target_path
+    dir_path = None
+    if create:
+        dir_path = target_path
+    elif create_parent:
+        dir_path = os.path.dirname(target_path)
+    if dir_path is not None:
+        if not os.path.exists(dir_path):
+            os.makedirs(dir_path, exist_ok=True)
+    return target_path
+
+
+def read_file(path: str, binary: bool = True) -> Union[str, bytes]:
+    with open(path, "rb" if binary else "rt") as f:
         return f.read()
 
 
 def write_file(path: str, data: [str, bytes]) -> None:
-    with open(path, "wb" if isinstance(data, bytes) else "w") as f:
+    with open(path, "wb" if isinstance(data, bytes) else "wt") as f:
         f.write(data)
 
 
@@ -352,22 +431,22 @@ def get_wan_ip() -> Optional[str]:
         return None
 
 
-def parse_version(version: str) -> [int, ...]:
+def parse_version(version: str) -> Tuple[int, ...]:
     result = []
     for x in version.split("."):
         if x.isdigit():
-            result.append(int(x))
+            result.append(cast_int(x))
         else:
             match = re.match(r"^\d+", x)
             if not match:
                 break
-            result.append(int(match.group(0)))
+            result.append(cast_int(match.group(0)))
     return tuple(result)
 
 
 def range_type(min: int, max: int):
     def wrapper(o):
-        value = int(o)
+        value = cast_int(o)
         if min <= value <= max:
             return value
         raise ValueError("value not in range %s-%s" % (min, max))
